==> nextcloud-27.1.11.tgz: nextcloud/apps/photos/l10n/nb.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Offentlig lenke",
    "Photos" : "Bilder",
    "On This Day" : "På denne dagen",
    "Your memories under your control" : "Dine minner under din kontroll",
    "All media" : "Alle mediefiler",
    "Videos" : "Filmer",
    "Albums" : "Album",
    "Collaborative albums" : "Samarbeidsalbum",
    "People" : "Mennesker",
    "Folders" : "Mapper",
    "Favorites" : "Favoritter",
    "On this day" : "På denne dagen",
    "Shared with you" : "Delt med deg",
    "Tags" : "Merkelapper",
    "Places" : "Steder",
    "Map" : "Kart",
    "Photos settings" : "Innstillinger for bilder",
    "Mark selection as favorite" : "Merk utvalget som favoritt",
    "Add selection to favorites" : "Legg til utvalg i favoritter",
    "Remove selection from favorites" : "Fjern utvalg fra favoritter",
    "Name of the album" : "Navn på albumet",
    "Location of the album" : "Plassering av albumet",
    "Back" : "Tilbake",
    "Add collaborators" : "Legg til samarbeidspartnere",
    "Save" : "Lagre",
    "Create album" : "Lag album",
    "Add to Album" : "Legg til album",
    "Add selection to album {albumName}" : "Legg til utvalg i albumet {albumName}",
    "Shared by" : "Delt av",
    "Create a new album." : "Opprett et nytt album.",
    "Create new album" : "Lag nytt album",
    "New album" : "Nytt album",
    "_%n item_::_%n photos and videos_" : ["%n element","%n bilder og videoer"],
    "Add people or groups who can edit your album" : "Legg til personer eller grupper som kan redigere albumet ditt",
    "Search people or groups" : "Søk etter personer eller grupper",
    "No recommendations. Start typing." : "Ingen anbefalinger. Start å skrive.",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "Fjern {collaboratorLabel} fra samarbeidspartnerlisten",
    "Copy the public link" : "Kopier den offentlige lenken",
    "Public link copied!" : "Offentlig lenke er kopiert!",
    "Copy public link" : "Kopier offentlig lenke",
    "Delete the public link" : "Slett den offentlige lenken",
    "Create public link share" : "Opprett offentlig koblingsdeling",
    "Share via public link" : "Del via offentlig lenke",
    "Failed to fetch collaborators list." : "Kunne ikke hente listen over samarbeidspartnere.",
    "Failed to update album." : "Kunne ikke oppdatere albumet.",
    "This collection does not exist" : "Denne samlingen eksisterer ikke",
    "An error occurred" : "En feil oppsto",
    "No picture for this day" : "Ikke noe bilde for denne dagen",
    "Picture taken on this day will show up here." : "Bilde tatt denne dagen vil dukke opp her.",
    "More photos from this day" : "Flere bilder fra denne dagen",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%nikke-tilordnet bilde","%n ikke-tilordnede bilder"],
    "Favorite" : "Favoritt",
    "Select image {imageName}" : "Velg bilde {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Favorittbilde, åpne {name}-bildet i full størrelse",
    "Open the full size \"{name}\" image" : "Åpne full størrelse av bildet \"{name}\"",
    "Open the \"{name}\" folder" : "Åpne {name}-mappen",
    "Go back" : "Gå tilbake",
    "Back to {folder}" : "Tilbake til {folder}",
    "Share this folder" : "Del denne mappen",
    "Dates" : "Datoer",
    "Jump to specific date in list" : "Gå til spesifikk dato i listen",
    "Jump to {date}" : "Gå til {date}",
    "Add to {destination}" : "Legg til i {destination}",
    "There are no photos or videos yet!" : "Det er ingen bilder eller videoer ennå!",
    "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
    "Enable squared photos view" : "Aktiver visning med kvadratiske bilder",
    "Delete source directory" : "Slett kildekatalog",
    "All folders" : "Alle mapper",
    "Select a source folder for your media" : "Velg en kildemappe for mediene dine",
    "Home" : "Hjem",
    "Choose default Photos upload and Albums location" : "Velg standard bildeopplasting og albumplassering",
    "Choose a different folder" : "Velg en annen mappe",
    "Select the default upload location for your media" : "Velg standard opplastingssted for mediene dine",
    "View" : "Vis",
    "Choose the folders from where photos and videos are shown." : "Velg mappene der bilder og videoer vises.",
    "Upload folder" : "Opplastingsmappe",
    "Choose the folder where photos and albums are uploaded to." : "Velg mappen der bilder og album lastes opp.",
    "_%n photo_::_%n photos_" : ["%n bilde","%n bilder"],
    "Unselect all" : "Fravelg alle",
    "Manage collaborators for this album" : "Administrer samarbeidspartnere for dette albumet",
    "Open actions menu" : "Åpne handlingsmenyen",
    "Edit album details" : "Rediger albumdetaljer",
    "Download all files in album" : "Last ned alle filene i albumet",
    "Delete album" : "Slett album",
    "Download selected files" : "Last ned valgte filer",
    "Remove selection from album" : "Fjern utvalg fra album",
    "This album does not have any photos or videos yet!" : "Dette albumet har ingen bilder eller videoer ennå!",
    "Add photos to this album" : "Legg til bilder i dette albumet",
    "Add photos to {albumName}" : "Legg bilder til {albumName}",
    "Manage collaborators" : "Administrer samarbeidspartnere",
    "Save collaborators for this album." : "Lagre samarbeidspartnere for dette albumet.",
    "Cover photo for album {albumName}" : "Forsidebilde for albumet {albumName}",
    "There is no album yet!" : "Det er ikke noe album ennå!",
    "This person could not be found" : "Denne personen ble ikke funnet",
    "Rename person" : "Gi nytt navn til person",
    "Merge with different person" : "Slå sammen med en annen person",
    "Download selected photos" : "Last ned valgte bilder",
    "Remove from favorites" : "Fjern fra favoritter",
    "Remove person" : "Fjern person",
    "Name of this person" : "Navnet på denne personen",
    "Save." : "Lagre.",
    "Merge person" : "Slå sammen person",
    "Move to different person" : "Flytt til en annen person",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Flytt bildet til en annen person","Flytt bilder til en annen person"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fjern bildet fra personen","Fjern bilder fra personen"],
    "This might take some time depending on the size of your photo library." : "Dette kan ta litt tid avhengig av størrelsen på bildebiblioteket ditt.",
    "Recognized people will show up here" : "Anerkjente personer vil dukke opp her",
    "This folder does not exist" : "Denne mappen finnes ikke",
    "Loading folders …" : "Laster inn mapper…",
    "No photos in here" : "Ingen bilder her",
    "Taken on {date} at {time}" : "Tatt på {date} kl. {time}",
    "This place does not have any photos or videos yet!" : "Denne plasseringen har ingen bilder eller video enda!",
    "Add photos to this place" : "Legg bilder til denne plasseringen",
    "Cover photo for place {placeName}" : "Forsidebilde for sted {placeName}",
    "There is no place yet!" : "Det er ingen steder enda!",
    "Cover photo for shared album {albumName}." : "Forsidebilde for delt album {albumName}.",
    "Back to tags overview" : "Tilbake til merkelappoversikt",
    "No photos with this tag yet" : "Ingen bilder med denne merkelappen ennå",
    "No tags yet" : "Ingen etiketter enda",
    "Photos with tags will show up here" : "Bilder med etiketter vises her",
    "Popular tags" : "Populære merkelapper",
    "Add" : "Legg til",
    "Add to album" : "Legg til i album",
    "Delete selection" : "Slett utvalg",
    "No photos or videos in here" : "Ingen bilder eller videoer her",
    "Unassigned faces" : "Ikke-tilordnede ansikter",
    "_%n photos_::_%n photos_" : ["%n bilder","%n bilder"],
    "Failed to fetch collection." : "Henting av samling feilet.",
    "Failed to fetch collections list." : "Henting av samlingslisten feilet",
    "Failed to fetch faces list." : "Kunne ikke hente ansiktslisten.",
    "All your media" : "Alle mediefilene dine",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Delte album",
    "Shared album {title}" : "Delt album {title}",
    "Public album {title}" : "Offentlig album {title}",
    "Tagged photos" : "Bilder med merkelapper",
    "Tagged photo {title}" : "Merket bilde {title}",
    "{title}'s face" : "{title} sitt ansikt",
    "{startDate} to {endDate}" : "{startDate} til {endDate}",
    "Details" : "Detaljer",
    "Failed to rename {oldName} to {faceName}." : "Kunne ikke endre navn på {oldName} til {faceName}.",
    "Failed to delete {faceName}." : "Kunne ikke slette {faceName}.",
    "Failed to delete {fileId}." : "Kunne ikke slette {fileId}.",
    "Failed to delete {fileName}." : "Kunne ikke slette {fileName}.",
    "Failed to set favorite state for {fileId}." : "Kunne ikke angi favorittstatus for {fileId}.",
    "Failed to set favorite state for {fileName}." : "Kunne ikke angi favorittstatus for {fileName}.",
    "Could not load photos folder" : "Kunne ikke laste bildemappen",
    "Go back to the previous view." : "Gå tilbake til forrige visning.",
    "Go to the add collaborators view." : "Gå til visningen Legg til samarbeidspartnere.",
    "Create the album." : "Lag albumet.",
    "Back to the new album form." : "Tilbake til albumskjemaet.",
    "_Share with %n user_::_Share with %n users_" : ["Del med %n bruker","Del med %n brukere"],
    "Search for collaborators" : "Søk etter samarbeidspartnere",
    "Add {collaboratorLabel} to the collaborators list" : "Legg til {collaboratorLabel} i samarbeidspartnerlisten",
    "No collaborators available" : "Ingen samarbeidspartnere tilgjengelig",
    "Failed to fetch album." : "Kunne ikke hente albumet.",
    "The file is in the favorites" : "Filen er i favorittene",
    "Open the \"{name}\" sub-directory" : "Åpne undermappen \"{name}\"",
    "Default Photos upload and Albums location" : "Standard bildeopplasting og albumplassering",
    "Select the default location for your media" : "Velg standardplassering for mediefilene dine",
    "Invalid location selected" : "Invalid location selected",
    "Photos directory" : "Bildemappe",
    "Add photos to the album" : "Legg til bilder i albumet",
    "Failed to fetch albums list." : "Kunne ikke hente albumlisten.",
    "Shared albums" : "Delte album",
    "Create a new album" : "Opprett et nytt album",
    "Add selection to an album" : "Legg til utvalg i et album",
    "Failed to create {albumName}." : "Kunne ikke opprette {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Kunne ikke endre navn på {currentAlbumName} til {newAlbumName}."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.8.tgz: nextcloud/apps/photos/l10n/nb.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Offentlig lenke",
    "Photos" : "Bilder",
    "On This Day" : "På denne dagen",
    "Your memories under your control" : "Dine minner under din kontroll",
    "All media" : "Alle mediefiler",
    "Videos" : "Filmer",
    "Albums" : "Album",
    "Collaborative albums" : "Samarbeidsalbum",
    "People" : "Mennesker",
    "Folders" : "Mapper",
    "Favorites" : "Favoritter",
    "On this day" : "På denne dagen",
    "Shared with you" : "Delt med deg",
    "Tags" : "Merkelapper",
    "Places" : "Steder",
    "Map" : "Kart",
    "Photos settings" : "Innstillinger for bilder",
    "Mark selection as favorite" : "Merk utvalget som favoritt",
    "Add selection to favorites" : "Legg til utvalg i favoritter",
    "Remove selection from favorites" : "Fjern utvalg fra favoritter",
    "Name of the album" : "Navn på albumet",
    "Location of the album" : "Plassering av albumet",
    "Back" : "Tilbake",
    "Add collaborators" : "Legg til samarbeidspartnere",
    "Save" : "Lagre",
    "Create album" : "Lag album",
    "Add to Album" : "Legg til album",
    "Add selection to album {albumName}" : "Legg til utvalg i albumet {albumName}",
    "Shared by" : "Delt av",
    "Create a new album." : "Opprett et nytt album.",
    "Create new album" : "Lag nytt album",
    "New album" : "Nytt album",
    "_%n item_::_%n photos and videos_" : ["%n element","%n bilder og videoer"],
    "Add people or groups who can edit your album" : "Legg til personer eller grupper som kan redigere albumet ditt",
    "Search people or groups" : "Søk etter personer eller grupper",
    "No recommendations. Start typing." : "Ingen anbefalinger. Start å skrive.",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "Fjern {collaboratorLabel} fra samarbeidspartnerlisten",
    "Copy the public link" : "Kopier den offentlige lenken",
    "Public link copied!" : "Offentlig lenke er kopiert!",
    "Copy public link" : "Kopier offentlig lenke",
    "Delete the public link" : "Slett den offentlige lenken",
    "Create public link share" : "Opprett offentlig koblingsdeling",
    "Share via public link" : "Del via offentlig lenke",
    "Failed to fetch collaborators list." : "Kunne ikke hente listen over samarbeidspartnere.",
    "Failed to update album." : "Kunne ikke oppdatere albumet.",
    "This collection does not exist" : "Denne samlingen eksisterer ikke",
    "An error occurred" : "En feil oppsto",
    "No picture for this day" : "Ikke noe bilde for denne dagen",
    "Picture taken on this day will show up here." : "Bilde tatt denne dagen vil dukke opp her.",
    "More photos from this day" : "Flere bilder fra denne dagen",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%nikke-tilordnet bilde","%n ikke-tilordnede bilder"],
    "Favorite" : "Favoritt",
    "Select image {imageName}" : "Velg bilde {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Favorittbilde, åpne {name}-bildet i full størrelse",
    "Open the full size \"{name}\" image" : "Åpne full størrelse av bildet \"{name}\"",
    "Open the \"{name}\" folder" : "Åpne {name}-mappen",
    "Go back" : "Gå tilbake",
    "Back to {folder}" : "Tilbake til {folder}",
    "Share this folder" : "Del denne mappen",
    "Dates" : "Datoer",
    "Jump to specific date in list" : "Gå til spesifikk dato i listen",
    "Jump to {date}" : "Gå til {date}",
    "Add to {destination}" : "Legg til i {destination}",
    "There are no photos or videos yet!" : "Det er ingen bilder eller videoer ennå!",
    "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
    "Enable squared photos view" : "Aktiver visning med kvadratiske bilder",
    "Delete source directory" : "Slett kildekatalog",
    "All folders" : "Alle mapper",
    "Add a Photos source for the timelines" : "Legg til en fotokilde for tidslinjene",
    "Add folder" : "Legg til mappe",
    "Select a source folder for your media" : "Velg en kildemappe for mediene dine",
    "Home" : "Hjem",
    "Choose default Photos upload and Albums location" : "Velg standard bildeopplasting og albumplassering",
    "Choose a different folder" : "Velg en annen mappe",
    "Select the default upload location for your media" : "Velg standard opplastingssted for mediene dine",
    "View" : "Vis",
    "Media folders" : "Mediemapper",
    "Choose the folders from where photos and videos are shown." : "Velg mappene der bilder og videoer vises.",
    "Upload folder" : "Opplastingsmappe",
    "Choose the folder where photos and albums are uploaded to." : "Velg mappen der bilder og album lastes opp.",
    "_%n photo_::_%n photos_" : ["%n bilde","%n bilder"],
    "Unselect all" : "Fravelg alle",
    "Manage collaborators for this album" : "Administrer samarbeidspartnere for dette albumet",
    "Open actions menu" : "Åpne handlingsmenyen",
    "Edit album details" : "Rediger albumdetaljer",
    "Download all files in album" : "Last ned alle filene i albumet",
    "Delete album" : "Slett album",
    "Download selected files" : "Last ned valgte filer",
    "Remove selection from album" : "Fjern utvalg fra album",
    "This album does not have any photos or videos yet!" : "Dette albumet har ingen bilder eller videoer ennå!",
    "Add photos to this album" : "Legg til bilder i dette albumet",
    "Add photos to {albumName}" : "Legg bilder til {albumName}",
    "Manage collaborators" : "Administrer samarbeidspartnere",
    "Save collaborators for this album." : "Lagre samarbeidspartnere for dette albumet.",
    "Cover photo for album {albumName}" : "Forsidebilde for albumet {albumName}",
    "There is no album yet!" : "Det er ikke noe album ennå!",
    "This person could not be found" : "Denne personen ble ikke funnet",
    "Rename person" : "Gi nytt navn til person",
    "Merge with different person" : "Slå sammen med en annen person",
    "Download selected photos" : "Last ned valgte bilder",
    "Remove from favorites" : "Fjern fra favoritter",
    "Remove person" : "Fjern person",
    "Name of this person" : "Navnet på denne personen",
    "Save." : "Lagre.",
    "Merge person" : "Slå sammen person",
    "Move to different person" : "Flytt til en annen person",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Flytt bildet til en annen person","Flytt bilder til en annen person"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fjern bildet fra personen","Fjern bilder fra personen"],
    "This might take some time depending on the size of your photo library." : "Dette kan ta litt tid avhengig av størrelsen på bildebiblioteket ditt.",
    "Recognized people will show up here" : "Anerkjente personer vil dukke opp her",
    "This folder does not exist" : "Denne mappen finnes ikke",
    "Loading folders …" : "Laster inn mapper…",
    "No photos in here" : "Ingen bilder her",
    "Taken on {date} at {time}" : "Tatt på {date} kl. {time}",
    "This place does not have any photos or videos yet!" : "Denne plasseringen har ingen bilder eller video enda!",
    "Add photos to this place" : "Legg bilder til denne plasseringen",
    "Cover photo for place {placeName}" : "Forsidebilde for sted {placeName}",
    "There is no place yet!" : "Det er ingen steder enda!",
    "Cover photo for shared album {albumName}." : "Forsidebilde for delt album {albumName}.",
    "Back to tags overview" : "Tilbake til merkelappoversikt",
    "No photos with this tag yet" : "Ingen bilder med denne merkelappen ennå",
    "No tags yet" : "Ingen etiketter enda",
    "Photos with tags will show up here" : "Bilder med etiketter vises her",
    "Popular tags" : "Populære merkelapper",
    "All tags" : "Alle tagger",
    "One of the source folders does not exists" : "En av kildemappene finnes ikke",
    "Add" : "Legg til",
    "Add to album" : "Legg til i album",
    "Delete selection" : "Slett utvalg",
    "No photos or videos in here" : "Ingen bilder eller videoer her",
    "Unassigned faces" : "Ikke-tilordnede ansikter",
    "_%n photos_::_%n photos_" : ["%n bilder","%n bilder"],
    "Failed to fetch collection." : "Henting av samling feilet.",
    "Failed to fetch collections list." : "Henting av samlingslisten feilet",
    "Failed to fetch faces list." : "Kunne ikke hente ansiktslisten.",
    "All your media" : "Alle mediefilene dine",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Delte album",
    "Shared album {title}" : "Delt album {title}",
    "Public album {title}" : "Offentlig album {title}",
    "Tagged photos" : "Bilder med merkelapper",
    "Tagged photo {title}" : "Merket bilde {title}",
    "{title}'s face" : "{title} sitt ansikt",
    "{startDate} to {endDate}" : "{startDate} til {endDate}",
    "Details" : "Detaljer",
    "Failed to rename {oldName} to {faceName}." : "Kunne ikke endre navn på {oldName} til {faceName}.",
    "Failed to delete {faceName}." : "Kunne ikke slette {faceName}.",
    "Failed to delete {fileId}." : "Kunne ikke slette {fileId}.",
    "Failed to delete {fileName}." : "Kunne ikke slette {fileName}.",
    "Failed to set favorite state for {fileId}." : "Kunne ikke angi favorittstatus for {fileId}.",
    "Failed to set favorite state for {fileName}." : "Kunne ikke angi favorittstatus for {fileName}.",
    "Could not load photos folder" : "Kunne ikke laste bildemappen",
    "Go back to the previous view." : "Gå tilbake til forrige visning.",
    "Go to the add collaborators view." : "Gå til visningen Legg til samarbeidspartnere.",
    "Create the album." : "Lag albumet.",
    "Back to the new album form." : "Tilbake til albumskjemaet.",
    "_Share with %n user_::_Share with %n users_" : ["Del med %n bruker","Del med %n brukere"],
    "Search for collaborators" : "Søk etter samarbeidspartnere",
    "Add {collaboratorLabel} to the collaborators list" : "Legg til {collaboratorLabel} i samarbeidspartnerlisten",
    "No collaborators available" : "Ingen samarbeidspartnere tilgjengelig",
    "Failed to fetch album." : "Kunne ikke hente albumet.",
    "The file is in the favorites" : "Filen er i favorittene",
    "Open the \"{name}\" sub-directory" : "Åpne undermappen \"{name}\"",
    "Default Photos upload and Albums location" : "Standard bildeopplasting og albumplassering",
    "Select the default location for your media" : "Velg standardplassering for mediefilene dine",
    "Invalid location selected" : "Invalid location selected",
    "Photos directory" : "Bildemappe",
    "Add photos to the album" : "Legg til bilder i albumet",
    "Failed to fetch albums list." : "Kunne ikke hente albumlisten.",
    "Shared albums" : "Delte album",
    "Create a new album" : "Opprett et nytt album",
    "Add selection to an album" : "Legg til utvalg i et album",
    "Failed to create {albumName}." : "Kunne ikke opprette {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Kunne ikke endre navn på {currentAlbumName} til {newAlbumName}."
},
"nplurals=2; plural=(n != 1);");
